abacusai.api_class.document_retriever — AbacusAI documentation

# `abacusai.api_class.document_retriever`

## Module Contents

### Classes

`VectorStoreConfig` | Configs for vector store indexing.
`DocumentRetrieverConfig` | Configs for document retriever.

class abacusai.api_class.document_retriever.VectorStoreConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Configs for vector store indexing.

  Parameters:

    - chunk_size (int) – The size of text chunks in the vector store.

    - chunk_overlap_fraction (float) – The fraction of overlap between chunks.

    - text_encoder (VectorStoreTextEncoder) – Encoder used to index texts from the documents.

    - chunk_size_factors (list) – Chunking data with multiple sizes. The specified list of factors are used to calculate more sizes, in addition to chunk_size.

    - score_multiplier_column (str) – If provided, will use the values in this metadata column to modify the relevance score of returned chunks for all queries.

  chunk_size: int
  chunk_overlap_fraction: float
  text_encoder: abacusai.api_class.enums.VectorStoreTextEncoder
  chunk_size_factors: list
  score_multiplier_column: str

class abacusai.api_class.document_retriever.DocumentRetrieverConfig

  Bases: `VectorStoreConfig`

  Configs for document retriever.